@@ -7,7 +7,11 @@ import time
 import re
 import ipaddress
 
-from typing import Optional, Text, Any, Tuple, Dict, Callable
+from logging import error
+
+from typing import Optional, Text, Tuple, Dict, Callable
+
+from act.types.format import ValidationError, format_threat_actor
 
 
 class ThreatLevelID(enum.Enum):
@@ -98,8 +102,12 @@ class Event:  # pylint: disable=R0902
 
     def __init__(self, loads: Optional[Text] = None) -> None:
         self._uuid: uuid.UUID = uuid.uuid4()
-        self.timestamp: int = int(time.time())  # Timestamp of event creation or event/attribute last update
-        self.publish_timestamp: int = int(time.time())  # reference time when the event was published on the instance.
+        self.timestamp: int = int(
+            time.time()
+        )  # Timestamp of event creation or event/attribute last update
+        self.publish_timestamp: int = int(
+            time.time()
+        )  # reference time when the event was published on the instance.
 
         if loads:
             data = json.loads(loads)
@@ -152,11 +160,21 @@ class Attribute:  # attributeattributes in misp babel pylint: disable=R0903
         try:
             self._uuid = attributedict["uuid"]
             self.id: Text = attributedict["uuid"]
-            mapper_fn = map_misp_to_act.get(attributedict["type"], lambda x: (None, None))
+            mapper_fn = map_misp_to_act.get(
+                attributedict["type"], lambda x: (None, None)
+            )
             self.act_type: Optional[Text] = None
             self.value: Optional[Text] = None
-            self.act_type, self.value = mapper_fn(attributedict["value"])
-            if "RelatedAttribute" in attributedict and attributedict["RelatedAttribute"]:
+
+            try:
+                self.act_type, self.value = mapper_fn(attributedict["value"])
+            except ValidationError as e:
+                error(str(e))
+
+            if (
+                "RelatedAttribute" in attributedict
+                and attributedict["RelatedAttribute"]
+            ):
                 print("DEBUG: {0}".format(attributedict["RelatedAttribute"]))
         except:  # noqa=E722 (silence Flake8; catching for logging and re-raise)
             print(attributedict)
@@ -179,7 +197,7 @@ def certificate_f(x: Text) -> Tuple[Text, Text]:
 
 def threat_actor_f(x: Text) -> Tuple[Text, Text]:
     """Translation function misp -> act"""
-    return "threatActor", x.lower()
+    return "threatActor", format_threat_actor(x)
 
 
 def campaign_f(x: Text) -> Tuple[Text, Text]:
